# Quple

A framework for quantum machine learning using the google cirq library

## Feature Map Tutorial

* Tutorial I: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/https://gitlab.cern.ch/clcheng/quple/-/raw/master/example/Feature_Map_Walkthrough.ipynb)
